.. Argentic documentation master file, created by
   sphinx-quickstart on Fri May 16 15:29:29 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Argentic's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Overview:

   ../../README.md 

.. toctree::
   :maxdepth: 2
   :caption: User Guide:

   # Add links to your user guide .md or .rst files here
   # Example: user_guide/getting_started.md

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   # Add links to your API documentation .md or .rst files here
   # Example: ../../src/your_module/api.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

